California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
AGUIRRE, RICHARD W. ALEXANDER, S. DEACON ALEXANDER, STEWART A. ALVAREZ, CARLOS ARIF, MOHAMMAD BROWN, EDMUND G. (JERRY) DARLING, LOWELL D. GREENE, VIBERT F. HUGHES, DOUGLAS RAYMOND MILLER, KENNETH J. NARITELLI, LAWRENCE A. NEWMAN II, ROBERT C. NEWSOM, GAVIN NIGHTINGALE, CHELENE H. OGDEN, DALE F. PINEDA JR., CHARLES POIZNER, STEVE ROBINSON, MARKHAM G. SCHURMAN, PETER SYMMON, JOSEPH M TULLY-SMITH, DAVID WELLS, LAURA WHITMAN, MARGARET C.
| LIEUTENANT GOVERNOR
AANESTAD, SAMUEL M. BROWN, PAMELA J. CASTILLO, JAMES R. DAVIS, BERT GIRARD, YVONNE R. HAHN, JANICE HARRIS, DAVID KING, JIM KOREVAAR, ERIC J. LEVITT, SCOTT L. MALDONADO, ABEL NEWSOM, GAVIN WEBER, C.T.
SECRETARY OF STATE
BOWEN, DEBRA CABRAL, MARYLOU DUNN, DAMON J. MENASCHE, ANN E. SHORT, MERTON D. TAITZ, ORLY TOBIN, CHRISTINA M.
| CONTROLLER
BELIZ, LAWRENCE G. CHIANG, JOHN EVANS, DAVID FAVOR, ANDREW H. FRANKEL, ROSS D. JOHNSON, NATHAN E. MARTINEZ, KAREN LOIS STRICKLAND, TONY
TREASURER
CRITTENDEN, CHARLES LAUTEN, ROBERT E. LOCKYER, BILL REIGER, DEBRA L. WALTERS, MIMI
| ATTORNEY GENERAL
ALLEN, PETER V. COOLEY, STEVE DELGADILLO, ROCKARD J. EASTMAN, JOHN C. EVANS, ROBERT J. HANNAN, TIMOTHY J. HARMAN, TOM HARRIS, KAMALA D. KELLY, CHRIS LIEU, TED NAVA, PEDRO I. SCHMIER, MICHAEL K. TEMPLIN, DIANE BEALL TORRICO, ALBERTO
SUPERINTENDENT OF PUBLIC INSTRUCTION
ACEVES, LARRY BLAKE, KAREN E. DELIGIANNI-BRYDGES, ALEXIA L. GUTIERREZ, LYDIA A. LENNING, DIANE A. MARTIN, LEONARD JAMES MC MICKEN, GRANT M. NUSBAUM, DANIEL ROMERO, GLORIA SHEIKH-NOOR, FAARAX DAHIR TORLAKSON, TOM WILLIAMS JR., HENRY L.
| INSURANCE COMMISSIONER
BALDERSTON, WILLIAM J. BRONSTEIN, RICHARD S. DE LA TORRE, HECTOR FITZGERALD, BRIAN DESMOND JONES, DAVE PADILLA, DINA J. PEDERSEN, CLAYTON E. VILLINES, MICHAEL N.
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
BORG, SHERILL L. FORD, TED MONTGOMERY, G. ALAN SCOTT, KEVIN R. WATSON, KENNITA L. WILLIAMS, RAE YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
ALBY, BARBARA J. AVILA, PAUL VINCENT MICHLIN, WILLARD D. MITCHELL-SAWYER, TOBY D. NAKANISHI, ALAN S. PARKER, CHRIS R. RUNNER, GEORGE C. STEBBINS, MARK L. STREICHMAN, EDWARD C.
MEMBER BOARD OF EQUALIZATION 03
BAKER, VICTOR G. DIXON, JERRY L. FINLEY, MARY LOU HEISING-CHRISTIAN, MARY LUSSENHEIDE, TERRI L. STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
DE BAETS, PETER D. HOFFMAN, SHAWN HORTON, JEROME E. LAWRENCE, NANCY
SENATE DISTRICTS
STATE SENATE 02
EVANS, NOREEN M. LYNCH, THOMAS DEAN ROSAS, DAVID C. SANDERS, JOANNE B. WIESNER, LAWRENCE R.
| STATE SENATE 04
GILL, LATHE SHELDON KEENE, RICHARD J. LA MALFA, DOUG
STATE SENATE 06
HYLAND, LANRIC STEINBERG, DARRELL TORNO, STEVE WEILAND, MARCEL C.
| STATE SENATE 08
PARK, DOO YEE, LELAND Y.
STATE SENATE 10
CHOU, IVAN C. CORBETT, ELLEN MAFFIT, ROBERT B.
| STATE SENATE 12
CABALLERO, ANNA CANNELLA, ANTHONY JOSEPH
STATE SENATE 14
BERRYHILL, TOM CAMPI, TIM J. DE ST. JEOR, BRET FULLER, HEIDI S. JOHNSON, LARRY MARSELLA, TOM
| STATE SENATE 16
RUBIO, MICHAEL J. THIESEN, TIMOTHY A. WYMAN, PHILLIP D.
STATE SENATE 18
FULLER, JEAN POPE, CARTER N.
| STATE SENATE 20
EVANS, KATHLEEN S. GALYSH, ADRIAN B. PADILLA, ALEX
STATE SENATE 22
DE LEON, KEVIN MENCHACA, ALEJANDRO REYES, EDWARD PAUL
| STATE SENATE 24
HERNANDEZ, EDWARD P. MORRISON, WILLIAM M.
STATE SENATE 26
HENDERSON, CINDY VARELA PRICE, CURREN D. SHIFREN, NACHUM WEBER, JR., ROBERT G.
| STATE SENATE 28
OROPEZA, JENNY RUSKIN, DAVID STAMMREICH, JOHN S.
STATE SENATE 30
CALDERON, RONALD JAIMES, NOEL A. WILLIS, WARREN P.
| STATE SENATE 32
DE VRIES, EARL MC LEOD, GLORIA NEGRETE
STATE SENATE 34
CORREA, LOU KRING, LUCILLE
| STATE SENATE 36
ANDERSON, JOEL C. CLAY, PAUL DICKSON, KENNETH C. METTI, MICHAEL S. STEPHENS, GREG A. STONE, JEFFREY E.
STATE SENATE 38
JONES, GILA STONE, KRISTI WYLAND, MARK B.
| STATE SENATE 40
HENDRY, BRIAN J. SALAS, MARY H. VARGAS, JUAN C.
ASSEMBLY DISTRICTS
ASSEMBLY 01
BROOKS, KAREN CHESBRO, WESLEY
| ASSEMBLY 02
HENNEMANN, RAYMOND G. NIELSEN, JIM SCHAUPP, CHARLES E.
ASSEMBLY 03
BILLECI, CHRISTINA R. BRYANT, GARY C. HARRINGTON, MICHAEL "MICKEY" LOGUE, DANIEL R.
| ASSEMBLY 04
CAMPANALE, DENNIS J. FREDERICK, DANIEL D. GAINES, EDWARD T KAMMERER, JOSEPH C.
ASSEMBLY 05
DE LUZ, CRAIG J. EDWARDS, MICHAEL J. GRAY, MATTHEW W. JONES, SUZANNE V. MARTINEZ, ELIZABETH S. MILES JR., LAWRENCE W. PAN, RICHARD PUGNO, ANDREW SHELBY, JAMES C. THOMPSON, DONALD VANDER VEEN, HANS C.
| ASSEMBLY 06
CONNALLY, PATRICK WM. HUFFMAN, JARED STEPHENS, ROBERT L.
ASSEMBLY 07
ALLEN, MICHAEL J. GENTRY, DORIS L. MOORE, KATHRYN N. PIERCE, LEE J. WILSON, MICHAEL L.
| ASSEMBLY 08
CONNOR, MICHELLE P. YAMADA, MARIKO M.
ASSEMBLY 09
COSTA, DANIEL A. DICKINSON, ROGER GARLAND, CHRIS HAMMOND, LAUREN MC CARTY, KEVIN REDDING, RICK D. SARTAIN, ADAM
| ASSEMBLY 10
BONSER, JANICE M. HUBER, ALYSON SIEGLOCK, JACK A. TROYER, ALBERT
ASSEMBLY 11
BONILLA, SUSAN CRAVEN, JULIE
| ASSEMBLY 12
FAUSTINO, ALFONSO S. MA, FIONA
ASSEMBLY 13
AMMIANO, TOM DEL CASTELLO, EVE F. PETER, LAURA A.
| ASSEMBLY 14
HATCHER, RYAN J. SKINNER, NANCY
ASSEMBLY 15
BUCHANAN, JOAN WILSON, ABRAM
| ASSEMBLY 16
FAISON, JAMES RINGER, LISA D. SWANSON, SANDRE
ASSEMBLY 17
GALGIANI, CATHLEEN MOBLEY JR., JACK M.
| ASSEMBLY 18
HAVIG, MICHAEL HAYASHI, MARY
ASSEMBLY 19
HILL, JERRY A. TUTIN, GARY WAISMAN, ALBERTO A.
| ASSEMBLY 20
SHAHAB, ADNAN I. WIECKOWSKI, ROBERT YEE, GARRETT S.
ASSEMBLY 21
BECKER, JOSH BELL, JR., RAYMOND M. CONLON, GREG GORDON, RICHARD S. KISHIMOTO, YORIKO
| ASSEMBLY 22
CAMPBELL, TIMOTHY J. (T.J.) FONG, PAUL HICKOK, ERIC
ASSEMBLY 23
CAMPOS, NORA ELIA MARTINEZ-ROACH, PATRICIA SAINI, ATUL
| ASSEMBLY 24
BEALL, JIM CHANDLER, ROBERT L. MC NEA, DOUGLAS A.
ASSEMBLY 25
CONRAD, BILL KEATING, JANICE E. MURRISON, TERRI OLSEN, KRISTIN M. VANDER WEIDE, KURT WHITE, JESSE J.
| ASSEMBLY 26
BERRYHILL, WILLIAM R. WEINTZ, TIM P.
ASSEMBLY 27
BLACK, LINDA "ELLIE" MONNING, WILLIAM W.
| ASSEMBLY 28
ALEJO, LUIS BARKER, ALLEN LLOYD BARNES, JANET V. BERNOSKY, ROBERT E. DOMINGUEZ, FRANCISCO
ASSEMBLY 29
ESSWEIN, MICHAEL J. HALDERMAN, LINDA F. MC KINNEY, DON (JAMES D.) WHALEN, ROBERT
| ASSEMBLY 30
CAMPBELL, STEPHANIE FLOREZ, FRAN PARRA, PETE H. VALADAO, DAVID G.
ASSEMBLY 31
CASTILLO, ROMELIA NINO PEREA, HENRY T. SHOEMAKER, BRANDON K. VELASCO, ROSALINE SERRATO
| ASSEMBLY 32
GROVE, SHANNON HOLLOWAY, SHANNON L. METTLER, KENNETH L. SPOHN-GROSS, HOLLY
ASSEMBLY 33
ACHADJIAN, KHATCHIK KOKKONEN, MATT POLSON, PAUL K. STRONG, FRED L. B. WATERFIELD, HENRIETTA CARMEN ZACARIAS, HILDA
| ASSEMBLY 34
CASTRO, ESMERALDA CONWAY, CONNIE
ASSEMBLY 35
GOLDBERG, DANIEL JORDAN, SUSAN STOKER, MIKE WILLIAMS, DAS
| ASSEMBLY 36
CAMPBELL, MAGGIE JONES, LINDA K. KNIGHT, STEVE WATKINS, SHAWNTRICE C.
ASSEMBLY 37
GORELL, JEFF HOWELL, ROBERT W. MASRY, FERIAL
| ASSEMBLY 38
CHRISTENSEN, PEGGY L. SHAW, DIANA SMYTH, CAMERON
ASSEMBLY 39
FUENTES, FELIPE LINDBLAD, JOHN P. (JACK)
| ASSEMBLY 40
BLUMENFIELD, BOB DE YOUNG, DENNIS
ASSEMBLY 41
BROWNLEY, JULIA RATHBUN, TERRENCE L.
| ASSEMBLY 42
FEUER, MICHAEL NELSON TOMAN, MARY A.
ASSEMBLY 43
GATTO, MIKE KEUROGHELIAN, CHAHE NAHABEDIAN, NAYIRI RAMANI, SUNDER
| ASSEMBLY 44
DAY, ALVARO G. KOLLIN, EYTAN PORTANTINO, ANTHONY
ASSEMBLY 45
CEDILLO, GILBERT OLIVOS, SUZANNE
| ASSEMBLY 46
PEREZ, JOHN A.
ASSEMBLY 47
CAGE, LADY GARCIA-RANGEL, RAFAEL JONES, ROBERT L. JONES-SAWYER SR., REGINALD BYRON MC GARY, SEAN P. MITCHELL, HOLLY J. NICOLETTI, ED
| ASSEMBLY 48
DAVIS, MIKE
ASSEMBLY 49
ENG, MICHAEL TAYLOR, BRADLEY J.
| ASSEMBLY 50
AVALOS, CARMEN LARA, RICARDO MARQUEZ, LUIS H. MELLANA JR., PAUL (P. J.) MILLER, GLADYS O. OLIVIER, ART
ASSEMBLY 51
BRADFORD, STEVEN SANTIAGO, CYNTHIA
| ASSEMBLY 52
HALL, ISADORE PATRICK, GWEN (BATISTE)
ASSEMBLY 53
ANDERSON, KATE BUTLER, BETSY GREEN, LISA A. KARNO, NICK LAU, JAMES MINTZ, NATHAN M. MUSULIN, ETHAN M. SAENZ, EDGAR THOTTAM, PETER L. WALLACE, DIANE WARD, MITCH
| ASSEMBLY 54
FLORES-GIBSON, MARTHA LOWENTHAL, BONNIE
ASSEMBLY 55
FURUTANI, WARREN SALABAJ, CHRISTOPHER J.
| ASSEMBLY 56
BESTWICK, HENRY J. MENDOZA, TONY
ASSEMBLY 57
CONTRERAS, ALFONSO C. GUTIERREZ, BRIAN A. HERNANDEZ, ROGER
| ASSEMBLY 58
CALDERON, CHARLES M. MAY, GARRETT M.
ASSEMBLY 59
BYE, IVER CALAYCAY, COREY L. DONNELLY, TIM FERNANDES, DAN GOSNEY, ROBERT D. HUNTER, KENNETH T. LANCASTER, CHRISTOPHER W. RILEY, ANTHONY TYLER, TONY WOODS, DARCEL
| ASSEMBLY 60
HAGMAN, CURT
ASSEMBLY 61
MOORS, RAYMOND KENNETH TORRES, NORMA
| ASSEMBLY 62
CARTER, WILMER AMINA ENSLEY, JEANE M. NAVARRO, GIL
ASSEMBLY 63
BOLDA, JACQUELINE CHABOT, PAUL R. GILBREATH, PATRICIA L. KURTH, DON MORRELL, MIKE NICKEL, HENRY WARREN, ACQUANETTA H. WICKMAN, RENEA
| ASSEMBLY 64
LEMASTERS TAHIR, JEFFREY MEDINA, JOSE J. NESTANDE, BRIAN
ASSEMBLY 65
COOK, PAUL J. WOOD, CARL W.
| ASSEMBLY 66
DYE, DOUGLAS JEFFRIES, KEVIN D.
ASSEMBLY 67
FREEMAN, ROSALIND A. SILVA, JAMES W.
| ASSEMBLY 68
DOVINH, JOE MANSOOR, ALLAN R. NGUYEN, PHU PHAM, LONG K.
ASSEMBLY 69
HAMMOND, ROBERT MORRIS SOLORIO, JOSE
| ASSEMBLY 70
AMANTE, JERRY CHOI, STEVEN FERGUSON, JAY B. FOX, MELISSA GLOVER, MICHAEL G. THARP, DEBORAH WAGNER, DON
ASSEMBLY 71
KEPHART, GARY R. MILLER, JEFF
| ASSEMBLY 72
NORBY, CHRIS RANDS, JANE A. UBALLE, ESIQUIO
ASSEMBLY 73
HARKEY, DIANE JONES, JUDITH E.
| ASSEMBLY 74
CRAWFORD, CRYSTAL GARRICK, MARTIN W. KING, PAUL
ASSEMBLY 75
CHADWICK, CHRISTOPHER A. FLETCHER, NATHAN B. GARVER, PAUL
| ASSEMBLY 76
ATKINS, TONI G. BAEHR, DANIEL H. BAR-LEV, NAOMI DENNEY, RALPH WARSCHAUER, THOMAS
ASSEMBLY 77
BELITZ, RICHARD G. HANSON, MARK N. JONES, BRIAN W. RUBIN, CHRISTINE WELLS, BILL
| ASSEMBLY 78
BLOCK, MARTY J. POWELL, RICK L. TURNER, EMMA
ASSEMBLY 79
DOYLE, JACK HUESO, BEN QUINONES, PEARL ROACH, DERRICK
| ASSEMBLY 80
PEREZ, V. MANUEL SANCHEZ, STEVE